=== modified file 'README'
--- README	2015-08-31 09:51:28 +0000
+++ README	2016-03-24 14:07:40 +0000
@@ -17,6 +17,9 @@
 To avoid building the tests (to speed up the build):
 $ cmake -DNO_TESTS=true
 
+To enable logging of Qt's OpenGL debug messages:
+$ cmake -DQGL_DEBUG=true
+
 To test the server, enter the demos directory, and run (NB: server should be run as root):
 
 $ sudo su

=== modified file 'src/platforms/mirserver/CMakeLists.txt'
--- src/platforms/mirserver/CMakeLists.txt	2016-03-14 11:09:12 +0000
+++ src/platforms/mirserver/CMakeLists.txt	2016-03-24 14:07:40 +0000
@@ -5,6 +5,11 @@
 pkg_check_modules(FONTCONFIG fontconfig REQUIRED)
 add_definitions(-DQ_FONTCONFIGDATABASE)
 
+if (QGL_DEBUG)
+    message(STATUS "Qt's OpenGL debug logging enabled.")
+    add_definitions(-DQGL_DEBUG)
+endif()
+
 #set(CMAKE_C_FLAGS "${CMAKE_C_FLAGS} -std=c11 -fPIC")
 
 # Dirty hack: The private QtPlatformSupport include dirs are not made available via

=== modified file 'src/platforms/mirserver/miropenglcontext.cpp'
--- src/platforms/mirserver/miropenglcontext.cpp	2016-02-05 22:53:46 +0000
+++ src/platforms/mirserver/miropenglcontext.cpp	2016-03-24 14:07:40 +0000
@@ -37,7 +37,7 @@
 
 MirOpenGLContext::MirOpenGLContext(const QSharedPointer<MirServer> &server, const QSurfaceFormat &format)
     : m_currentWindow(nullptr)
-#ifndef QT_NO_DEBUG
+#ifdef QGL_DEBUG
       , m_logger(new QOpenGLDebugLogger(this))
 #endif
 {
@@ -84,7 +84,7 @@
     m_format.setStencilBufferSize(server->the_gl_config()->stencil_buffer_bits());
     m_format.setSamples(-1);
 
-#ifndef QT_NO_DEBUG
+#ifdef QGL_DEBUG
     const char* string = (const char*) glGetString(GL_VENDOR);
     qDebug() << "OpenGL ES vendor: " << qPrintable(string);
     string = (const char*) glGetString(GL_RENDERER);
@@ -135,7 +135,7 @@
         m_currentWindow = screenWindow;
         screenWindow->makeCurrent();
 
-#ifndef QT_NO_DEBUG
+#ifdef QGL_DEBUG
         if (!m_logger->isLogging() && m_logger->initialize()) {
             m_logger->startLogging(QOpenGLDebugLogger::SynchronousLogging);
             m_logger->enableMessages();

=== modified file 'src/platforms/mirserver/miropenglcontext.h'
--- src/platforms/mirserver/miropenglcontext.h	2016-02-05 22:53:46 +0000
+++ src/platforms/mirserver/miropenglcontext.h	2016-03-24 14:07:40 +0000
@@ -19,7 +19,7 @@
 
 #include <qpa/qplatformopenglcontext.h>
 
-#ifndef QT_NO_DEBUG
+#ifdef QGL_DEBUG
 #include <QOpenGLDebugLogger>
 #endif
 
@@ -44,14 +44,14 @@
 
     QFunctionPointer getProcAddress(const QByteArray &procName) override;
 
-#ifndef QT_NO_DEBUG
+#ifdef QGL_DEBUG
     Q_SLOT void onGlDebugMessageLogged(QOpenGLDebugMessage m) { qDebug() << m; }
 #endif
 
 private:
     QSurfaceFormat m_format;
     ScreenWindow *m_currentWindow;
-#ifndef QT_NO_DEBUG
+#ifdef QGL_DEBUG
     QOpenGLDebugLogger *m_logger;
 #endif
 };

